About
=====

The `Diofant`_ project is a fork of the `SymPy`_, started by Sergey B
Kirpichev, last regular SymPy's commit is :commit:`cbdd072`, (22 Feb
2015).  The git history goes back to 2007, when development was in svn.

The project was named after the Diophantus of Alexandria.  His
"Arithmetica" is one of the earliest known texts that use symbols in
equations.  "Diofant" is a transliteration of Диофант, from Russian.

License
-------

Unless stated otherwise, all files in the Diofant project are licensed
using the new BSD license:

.. literalinclude:: ../LICENSE
    :language: none

SymPy Development Team
----------------------

SymPy is a team project and it was developed by a lot of people.
Please refer to the `AUTHORS
<https://github.com/sympy/sympy/blob/master/AUTHORS>`_ file in the
`SymPy repository <https://github.com/sympy/sympy/>`_ for up-to-date
list of contributors.

Please note that that list is incomplete intentionally, because some
former SymPy developers don't want to be mentioned in the context of
the SymPy or derived projects.

Brief History
-------------

`SymPy`_ was started by Ondřej Čertík in 2005, he wrote some code during the
summer, then he wrote some more code during the summer 2006. In February 2007,
Fabian Pedregosa joined the project and helped fixed many things, contributed
documentation and made it alive again. 5 students (Mateusz Paprocki, Brian
Jorgensen, Jason Gedge, Robert Schwarz and Chris Wu) improved SymPy incredibly
during the summer 2007 as part of the Google Summer of Code (GSoC). Pearu Peterson
joined the development during the summer 2007 and he has made SymPy much more
competitive and fast (from 10x to 100x) by rewriting the core from scratch.
Jurjen N.E. Bos has contributed pretty printing and other patches.
Fredrik Johansson has wrote mpmath and contributed a lot of patches.

SymPy has participated in every GSoC since 2007.  Moderate amount
of SymPy's development has come from GSoC students.

In 2011, Ondřej Čertík stepped down as lead developer, with Aaron Meurer, who
also started as a GSoC student, taking his place.

Ondřej Čertík is still active in the community, but is too busy with work
and family to play a lead development role.  Unfortunately, his remaining
activity neither constructive nor productive anymore and SymPy just
slowly dies now: most former contributors are inactive now or
explicitly leaving this "friendly and welcoming" project.

This unfortunate situation was major reason to fork the
SymPy as the `Diofant`_ project.  Development in the new project will
be open and public, without hidden double standards, centered about
good, proved code and not project popularity counters.  Here we believe
that mathematical correctness is more important than political one.

.. _SymPy : http://www.sympy.org/
.. _Diofant : https://diofant.readthedocs.io/en/latest/
